LanguageService class

Constructors

LanguageService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

currentLanguage → RxString
final

Static Methods

getCurrentLanguage() Future<String>
Optional: Retrieves the currently stored language without modifying it
getOrStoreLanguage({String? language}) Future<String>
Gets the stored language, or stores the given one.
setLanguage(String language) Future<void>
Optional: Allows changing the language manually